-- version and date
local revision = tonumber(("$Revision: 46733 $"):match("%d+"))
if not NSD_REVISION or revision > NSD_REVISION then
    NSD_REVISION = revision
    NSD_DATE = ("$Date: 2007-08-16 22:46:36 -0400 (Thu, 16 Aug 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

-- localisations
local L = AceLibrary("AceLocale-2.2"):new("ShakedownDBM")
L:RegisterTranslations("enUS", function() return {
    ["Deadly Boss Mods"] = true,
    ["Raid Warning"] = true,
    ["Local Warning"] = true,
} end)

-- constants
local MSG_FREQUENCY = 2
local BAR_FREQUENCY = 21

-- create the class
local AceOO = AceLibrary("AceOO-2.0")
Addon = AceOO.Class(ShakedownAddonBase, "AceEvent-2.0")

-- constructor
function Addon.prototype:init()
    Addon.super.prototype.init(self, "DBM_GUI", L["Deadly Boss Mods"])
end

-- members
Addon.prototype.RWdeltaX = 0
Addon.prototype.RWdeltaY = 0
Addon.prototype.SWdeltaX = 0
Addon.prototype.SWdeltaY = 0

function Addon.prototype:Activate()

    if not Addon.super.prototype.Activate(self) then return end
    
    -- show a message now
    self:ShowMessage()
    
    -- show bar now
    self:ShowBar()

    --schedule repeating messages and bars
    self:ScheduleRepeatingEvent("DBMShakedownMessage", self.ShowMessage, MSG_FREQUENCY, self)
    self:ScheduleRepeatingEvent("DBMShakedownBar", self.ShowBar, BAR_FREQUENCY, self)
    
    -- show the distance frame
    if not DBMDistanceFrame or not DBMDistanceFrame:GetObject():IsShown() then
        DBM_Gui_DistanceFrame()
    end

    -- make the warning frames draggable
    self:MakeDraggable(RaidWarningFrame)
    self:MakeDraggable(DBMWarningFrame)
    
    -- calculate the co-ord delta between that which we get from GetPoint and the top centre aligned co-ords that DBM works with for raid warning
    RaidWarningFrame:StartMoving()
    RaidWarningFrame:StopMovingOrSizing()
    local _, _, _, x, y = RaidWarningFrame:GetPoint()
    self.RWdeltaX = DBM.Options.Gui.RaidWarning_PosX - x
    self.RWdeltaY = DBM.Options.Gui.RaidWarning_PosY - y
    
    -- calculate the co-ord delta between that which we get from GetPoint and the bottom centre aligned co-ords that DBM works with for raid warning
    DBMWarningFrame:StartMoving()
    DBMWarningFrame:StopMovingOrSizing()
    local _, _, _, x, y = DBMWarningFrame:GetPoint()
    self.SWdeltaX = DBM.Options.Gui.SelfWarning_PosX - x
    self.SWdeltaY = DBM.Options.Gui.SelfWarning_PosY - y
end

function Addon.prototype:Deactivate()

    Addon.super.prototype.Deactivate(self)

    -- check existence
    if not DBMGUI_VERSION then return end
    
    -- hide the dragbar
    DBM_StatusBarTimerDrag:Hide()
        
    -- hide the distance frame
    DBM_Gui_DistanceFrame()

    -- remove the draggable raid warning frames
    self:MakeUnDraggable(RaidWarningFrame)
    self:MakeUnDraggable(DBMWarningFrame)
    
    -- kill the scheduled messages and bars
    self:CancelScheduledEvent("DBMShakedownMessage")
    self:CancelScheduledEvent("DBMShakedownBar")

end

function Addon.prototype:ShowMessage()

    RaidWarningFrames_AddLocalMessages(DBMGUI_RAIDWARNING_EXAMPLE)
    DBM.HasAggro(L["Deadly Boss Mods"])
    
end

function Addon.prototype:ShowBar()

    DBM_StatusBarTimerDrag:Show()
    
end

function Addon.prototype:DragStart(this)

    this.isDragging = true
	this:StartMoving()
end

function Addon.prototype:DragStop(this)

    this:StopMovingOrSizing()
    this.isDragging = false
    
    local frameName = this:GetName()
    local _, _, _, x, y = this:GetPoint()
    if frameName == "RaidWarningFrame" then
        DBM.Options.Gui.RaidWarning_PosX = x + self.RWdeltaX
        DBM.Options.Gui.RaidWarning_PosY = y + self.RWdeltaY
    elseif frameName == "DBMWarningFrame" then
        DBM.Options.Gui.SelfWarning_PosX = x + self.SWdeltaX
        DBM.Options.Gui.SelfWarning_PosY = y + self.SWdeltaY
    end                                 
    
end

function Addon.prototype:MakeDraggable(frame)
    
    frame:SetBackdrop({ bgFile = self.backdropMayDrag, })
    frame:EnableMouse(true)
    frame:SetMovable(true)
    frame:RegisterForDrag("LeftButton")
    frame:SetScript("OnDragStart", function(this) self:DragStart(this) end)
	frame:SetScript("OnDragStop", function(this) self:DragStop(this) end)
    
end

function Addon.prototype:MakeUnDraggable(frame)
    
    frame:SetBackdrop({})
    frame:EnableMouse(false)
    frame:SetMovable(false)
    
end

-- create the instance of this class
local thisAddon = Addon:new()
